@@ -1,16 +1,15 @@
 package Tangerine;
-$Tangerine::VERSION = '0.21';
+$Tangerine::VERSION = '0.22';
 # ABSTRACT: Examine perl files and report dependency metadata
 use 5.010;
 use strict;
 use warnings;
 use utf8;
 use PPI;
-use List::Util 1.33 qw(any none);
 use Scalar::Util qw(blessed);
 use Tangerine::Hook;
 use Tangerine::Occurence;
-use Tangerine::Utils qw(accessor addoccurence);
+use Tangerine::Utils qw(any accessor addoccurence none);
 
 sub new {
     my $class = shift;
