@@ -1,12 +1,11 @@
 package Tangerine::hook::if;
-$Tangerine::hook::if::VERSION = '0.21';
+$Tangerine::hook::if::VERSION = '0.22';
 use 5.010;
 use strict;
 use warnings;
 use parent 'Tangerine::Hook';
-use List::Util 1.33 qw(any);
 use Tangerine::HookData;
-use Tangerine::Utils qw(stripquotelike $vre);
+use Tangerine::Utils qw(any stripquotelike $vre);
 
 
 sub run {
