@@ -1,19 +1,18 @@
 package Tangerine::hook::list;
-$Tangerine::hook::list::VERSION = '0.21';
+$Tangerine::hook::list::VERSION = '0.22';
 use 5.010;
 use strict;
 use warnings;
 use parent 'Tangerine::Hook';
-use List::Util 1.33 qw(any);
 use Tangerine::HookData;
 use Tangerine::Occurence;
-use Tangerine::Utils qw(stripquotelike $vre);
+use Tangerine::Utils qw(any stripquotelike $vre);
 
 sub run {
     my ($self, $s) = @_;
     if ((any { $s->[0] eq $_ } qw(use no)) && scalar(@$s) > 2 &&
         (any { $s->[1] eq $_ }
-            qw(aliased base mixin::with Mojo::Base ok parent superclass
+            qw(aliased base mixin mixin::with Mojo::Base ok parent superclass
                Test::Class::Most))) {
         my ($version) = $s->[2] =~ $vre;
         $version //= '';
@@ -30,7 +29,8 @@ sub run {
                 if $s->[1] eq 'Mojo::Base';
         }
         @args = $args[0]
-            if $args[0] && any { $s->[1] eq $_ } qw/aliased mixin::with Mojo::Base ok/;
+            if $args[0] && any { $s->[1] eq $_ }
+                qw/aliased mixin mixin::with Mojo::Base ok/;
         if ($s->[1] eq 'Test::Class::Most') {
             my $tcmparent;
             my @results;
@@ -86,13 +86,14 @@ Tangerine::hook::list - Process simple module lists
 This hook catches C<use> statements with modules loading more modules
 listed as their arguments.
 
-Currently this hook knows about L<aliased>, L<base>, L<Mojo::Base>,
-L<Test::use::ok>, L<parent>, L<superclass> and L<Test::Class::Most>.
+Currently this hook knows about L<aliased>, L<base>, L<mixin>, L<mixin::with>,
+L<Mojo::Base>, L<Test::use::ok>, L<parent>, L<superclass> and
+L<Test::Class::Most>.
 
 =head1 SEE ALSO
 
-L<Tangerine>, L<aliased>, L<base>, L<Mojo::Base>, L<Test::use::ok>, L<parent>,
-L<superclass>, L<Test::Class::Most>
+L<Tangerine>, L<aliased>, L<base>, L<mixin>, L<mixin::with>, L<Mojo::Base>,
+L<Test::use::ok>, L<parent>, L<superclass>, L<Test::Class::Most>
 
 =head1 AUTHOR
 
