@@ -1,11 +1,10 @@
 package Tangerine::hook::moduleload;
-$Tangerine::hook::moduleload::VERSION = '0.21';
+$Tangerine::hook::moduleload::VERSION = '0.22';
 use strict;
 use warnings;
 use parent 'Tangerine::Hook';
-use List::Util 1.33 qw(any);
 use Tangerine::HookData;
-use Tangerine::Utils qw(stripquotelike);
+use Tangerine::Utils qw(any stripquotelike);
 
 sub run {
     my ($self, $s) = @_;
@@ -18,7 +17,6 @@ sub run {
     if ($self->type eq 'runtime' && (any { $s->[0] eq $_ } @routines) &&
         scalar(@$s) > 2)
     {
-        print "I would return: use ".join(' ', @$s[1..$#$s])."\n";
         return Tangerine::HookData->new(
             children => [ 'use', stripquotelike($s->[1]), @$s[2..$#$s] ],
             type => 'runtime',
