@@ -1,12 +1,11 @@
 package Tangerine::hook::testloading;
-$Tangerine::hook::testloading::VERSION = '0.21';
+$Tangerine::hook::testloading::VERSION = '0.22';
 use strict;
 use warnings;
 use parent 'Tangerine::Hook';
-use List::Util 1.33 qw(any);
 use Tangerine::HookData;
 use Tangerine::Occurence;
-use Tangerine::Utils qw(stripquotelike);
+use Tangerine::Utils qw(any stripquotelike);
 
 sub run {
     my ($self, $s) = @_;
