@@ -1,13 +1,12 @@
 package Tangerine::hook::xxx;
-$Tangerine::hook::xxx::VERSION = '0.21';
+$Tangerine::hook::xxx::VERSION = '0.22';
 use 5.010;
 use strict;
 use warnings;
 use parent 'Tangerine::Hook';
-use List::Util 1.33 qw(any);
 use Tangerine::HookData;
 use Tangerine::Occurence;
-use Tangerine::Utils qw/stripquotelike/;
+use Tangerine::Utils qw/any stripquotelike/;
 
 sub run {
     my ($self, $s) = @_;
